@@ -104,6 +104,7 @@ class KubeModel(ABC):
         """
         optimizer = self.configure_optimizers()
         self.optimizer = optimizer
+        self._save_optimizer_redis()
         # TODO here the state loaded should be the averaged one not the saved from earlier
 
         # self._load_optimizer_state()
@@ -137,6 +138,33 @@ class KubeModel(ABC):
             pickle.dump(self.optimizer.state_dict(), f)
         print('saved state')
 
+    def _save_optimizer_redis(self):
+        """
+        Saves the optimizer to the redis
+        """
+        job_id = self.args._job_id
+        func_id = self.args._func_id
+
+        self.logger.debug("Saving optimizer to the database")
+
+        weight_key = f'{job_id}:optimizer:{func_id}' 
+        pickled_val  = pickle.dumps(self.optimizer.state_dict())
+        self._redis_client.set(weight_key, pickled_val)
+
+        self.logger.debug('Saved optimizer to the database')
+
+    def _load_optimizer_redis(self):
+        """
+        Checks for a previously saved state of the optimizer and loads it from redis
+        """
+
+        job_id = self.args._job_id
+        func_id = self.args._func_id
+        weight_key = f'{job_id}:optimizer:{func_id}' 
+        pickled_val = self._redis_client.get(weight_key)
+        opt_states = pickle.loads(pickled_val)  
+        self.optimizer.load_state_dict(opt_states)
+
     def _get_logger(self):
         """
         Sets the current logger within the network according to the flask context
@@ -203,7 +231,6 @@ class KubeModel(ABC):
         :return:
         """
         self.__save_model()
-
         #pass
         # self._save_optimizer_state()
 
@@ -216,6 +243,7 @@ class KubeModel(ABC):
         :return:
         """
         self.__load_model()
+        self._load_optimizer_redis()
         #self._reset_optimizer_state()
 
     def _on_iteration_end(self):
@@ -224,6 +252,8 @@ class KubeModel(ABC):
         :return:
         """
         self.__save_model()
+        self._save_optimizer_redis()
+
 
     def _batch_to_device(self, batch: Union[torch.Tensor, Iterable[torch.Tensor]]):
         """
